<template>
  <div ref="chartContainer" :style="{ height: height, width: width }"></div>
</template>

<script>
import * as echarts from 'echarts';

export default {
  name: 'BarChart',
  props: {
    width: {
      type: String,
      default: '100%'
    },
    height: {
      type: String,
      default: '700px'
    },
    // 通过 props 传递颜色数据
    colors: {
      type: Array,
      default: () => ['#074cad', '#91cc75', '#fac858', '#ee6666'],
    },
    // 通过 props 传递配置数据
    chartData: {
      type: Object,
      required: true,
    },
  },
  data() {
    return {
      chartInstance: null,
    };
  },
  mounted() {
    this.initChart();
  },
  beforeDestroy() {
    if (this.chartInstance) {
      this.chartInstance.dispose();
    }
  },
  methods: {
    initChart() {
      // 初始化图表
      this.chartInstance = echarts.init(this.$refs.chartContainer);

      // 配置项
      const option = this.generateOption(this.chartData, this.colors);

      // 设置图表配置
      this.chartInstance.setOption(option);

      // 图表自适应窗口大小变化
      window.addEventListener('resize', this.resizeChart);
    },
    generateOption(data, colors) {
      const posList = [
        'left',
        'right',
        'top',
        'bottom',
        'inside',
        'insideTop',
        'insideLeft',
        'insideRight',
        'insideBottom',
        'insideTopLeft',
        'insideTopRight',
        'insideBottomLeft',
        'insideBottomRight',
      ];

      const labelOption = {
        show: true,
        position: data.position || 'insideBottom',
        distance: data.distance || 15,
        align: data.align || 'left',
        verticalAlign: data.verticalAlign || 'middle',
        rotate: data.rotate || 90,
        // formatter: '{c}  {name|{a}}',
        fontSize: 16,
        rich: {
          name: {},
        },
      };

      const option = {
        tooltip: {
          trigger: 'axis',
          axisPointer: {
            type: 'shadow',
          },
        },
        legend: {
          data: data.legendData,
          textStyle: {
            color: '#1890ff' // 标题文字颜色
          }
        },
        toolbox: {
          show: true,
          orient: 'vertical',
          left: 'right',
          top: 'center',
          feature: {
            mark: { show: true },
            dataView: { show: true, readOnly: false },
            magicType: { show: true, type: ['line', 'bar', 'stack'] },
            restore: { show: true },
            saveAsImage: { show: true },
          },
        },
        xAxis: [
          {
            position: 'bottom',
            name: '设备编号',
            type: 'category',
            axisTick: { show: false },
            data: data.xAxisData,
            axisLine: {
              onZero: false
            },//轴线是否在0刻度关闭，x轴名称时跟随轴线的
          },
        ],
        yAxis: [
          {
            name: '单位（毫米）',
            type: 'value',

          },
        ],
        series: data.seriesData
          ? data.seriesData.map((series, index) => ({
            ...series,
            type: 'bar',
            // label: labelOption,
            // label: {
            //   show: false, // 不显示标签
            // },
            itemStyle: {
              color: colors[index % colors.length], // 设置柱状图颜色
            },
            emphasis: {
              focus: 'series',
            },
          }))
          : [
            {
              name: '',
              data: [],
              itemStyle: {
                color: colors[0], // 设置柱状图颜色
              },
            },
            {
              name: '',
              data: [],
              itemStyle: {
                color: colors[1], // 设置柱状图颜色
              },
            },
            {
              name: '',
              data: [],
              itemStyle: {
                color: colors[2], // 设置柱状图颜色
              },
            },
            {
              name: '',
              data: [],
              itemStyle: {
                color: colors[3], // 设置柱状图颜色
              },
            },
          ],
      };

      return option;
    },
    resizeChart() {
      if (this.chartInstance) {
        this.chartInstance.resize();
      }
    },
  },
};
</script>

<style scoped>
.chart-container {
  width: 100%;
  height: 400px;
}
</style>